ApiServiceError class

API service configuration error (HTTP 483, 484, 485).

Occurs when:

  • HTTP 483: API key type doesn't match the service
  • HTTP 484: API key not whitelisted for this scope
  • HTTP 485: Service not enabled for this API key
Inheritance

Constructors

ApiServiceError(String message, {String? details})
Creates an ApiServiceError instance.
const

Properties

details String?
Optional additional details about the error.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
The error message.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited