CoordinateParseError class
Invalid coordinate parameters error (HTTP 470).
Occurs when the latitude or longitude values are invalid.
- Inheritance
-
- Object
- NeshanApiError
- CoordinateParseError
Constructors
- CoordinateParseError(String message, {String? details})
-
Creates a CoordinateParseError instance.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited