InvalidApiKeyError class

Invalid or missing API key error (HTTP 480).

Occurs when:

  • The API key is invalid
  • The API key is not provided in the request header
Inheritance

Constructors

InvalidApiKeyError(String message, {String? details})
Creates an InvalidApiKeyError instance.
const

Properties

details String?
Optional additional details about the error.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
The error message.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited