InvalidArgumentError class

Invalid request parameters error (HTTP 400).

Occurs when the request parameters are malformed or invalid.

Inheritance

Constructors

InvalidArgumentError(String message, {String? details})
Creates an InvalidArgumentError instance.
const

Properties

details String?
Optional additional details about the error.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
The error message.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited