NeshanApiError class sealed

Base sealed class for all Neshan API errors.

This sealed class hierarchy provides type-safe error handling for all Neshan APIs (reverse geocoding, search, etc.). Each error type corresponds to specific HTTP error codes returned by the APIs.

Based on Neshan API error codes:

Implementers

Properties

details String?
Optional additional details about the error.
final
hashCode int
The hash code for this object.
no setterinherited
message String
The error message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited