geocodingDebounce property
Debounce duration for reverse-geocoding API calls.
When the user moves the map, the reverse-geocoding API is not called immediately. Instead, it waits for this duration after the user stops moving the map to avoid making too many API requests.
Default is 300 milliseconds.
Implementation
final Duration geocodingDebounce;