searchDebounce property

Duration searchDebounce
final

Debounce duration for search input.

When the user types in the search field, the search API is not called immediately. Instead, it waits for this duration after the user stops typing to avoid making too many API requests.

Default is 300 milliseconds.

Implementation

final Duration searchDebounce;