NotFoundError class
Location not found error (HTTP 404).
Occurs when no address/results are found for the given coordinates or search term.
- Inheritance
-
- Object
- NeshanApiError
- NotFoundError
Constructors
- NotFoundError(String message, {String? details})
-
Creates a NotFoundError instance.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited