ParseError class

Response parsing error.

Occurs when the API response cannot be parsed as expected.

Inheritance

Constructors

ParseError(String message, {String? details})
Creates a ParseError instance.
const

Properties

details String?
Optional additional details about the error.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
The error message.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited