formattedAddress property
Complete formatted address including state, city, neighborhood, and street.
Implementation
final String formattedAddress;
Complete formatted address including state, city, neighborhood, and street.
final String formattedAddress;