map library

Map module for the neshan_maps_flutter package.

This module provides core map functionality including:

Usage

import 'package:neshan_maps_flutter/map.dart';
import 'package:latlong2/latlong.dart';

NeshanMap(
  mapKey: 'your-api-key',
  config: NeshanMapConfig(
    initialCenter: LatLng(35.6892, 51.3890),
  ),
  polygons: [
    NeshanPolygon(
      id: 'area1',
      coordinates: [/* ... */],
      fillColor: Colors.blue.withOpacity(0.3),
    ),
  ],
);

Classes

NeshanCircle
A model representing a circle on a Neshan map.
NeshanMap
A cross-platform widget that displays a Neshan map.
NeshanMapConfig
Viewport and style configuration for initializing a NeshanMap.
NeshanMapController
Controller for programmatically controlling the Neshan map.
NeshanMarker
A model representing a marker on a Neshan map.
NeshanPolygon
A model representing a polygon on a Neshan map.
NeshanPolyline
A model representing a polyline (line/path) on a Neshan map.

Enums

NeshanMapType
Enum representing the different types of Neshan maps available.

Constants

neshanMapHtmlAssetPath → const String
Path to the HTML asset file for the Neshan map.

Typedefs

NeshanErrorCallback = void Function(String message, Exception? exception, StackTrace? stackTrace)
Callback that is called when an error occurs.