circles property

List<NeshanCircle> circles
final

Initial list of circles to display on the map.

These circles are placed on the map when it first finishes loading. To add, remove, or replace circles after the map has loaded, use the methods on controller (NeshanMapController.addCircle, NeshanMapController.removeCircle, NeshanMapController.updateCircles, NeshanMapController.clearCircles).

Defaults to an empty list.

Implementation

final List<NeshanCircle> circles;