onCircleTapped property
Called when a circle on the map is tapped.
Receives the NeshanCircle.id of the tapped circle.
Implementation
final void Function(String circleId)? onCircleTapped;
Called when a circle on the map is tapped.
Receives the NeshanCircle.id of the tapped circle.
final void Function(String circleId)? onCircleTapped;