onLocationError property
Called when a location-related error occurs.
Covers permission denied, location service disabled, and tracking errors.
Implementation
final NeshanErrorCallback? onLocationError;
Called when a location-related error occurs.
Covers permission denied, location service disabled, and tracking errors.
final NeshanErrorCallback? onLocationError;