onMarkerTapped property
Called when a marker on the map is tapped.
Receives the NeshanMarker.id of the tapped marker.
Implementation
final void Function(String markerId)? onMarkerTapped;
Called when a marker on the map is tapped.
Receives the NeshanMarker.id of the tapped marker.
final void Function(String markerId)? onMarkerTapped;