onPolygonTapped property
Called when a polygon on the map is tapped.
Receives the NeshanPolygon.id of the tapped polygon.
Implementation
final void Function(String polygonId)? onPolygonTapped;
Called when a polygon on the map is tapped.
Receives the NeshanPolygon.id of the tapped polygon.
final void Function(String polygonId)? onPolygonTapped;