onPolylineTapped property
Called when a polyline on the map is tapped.
Receives the NeshanPolyline.id of the tapped polyline.
Implementation
final void Function(String polylineId)? onPolylineTapped;
Called when a polyline on the map is tapped.
Receives the NeshanPolyline.id of the tapped polyline.
final void Function(String polylineId)? onPolylineTapped;