dispose method
void
dispose()
Disposes of the controller and cleans up resources.
Call this when the controller is no longer needed to prevent memory leaks. This is particularly important if you create a controller but the widget is disposed before the map becomes ready.
Example:
@override
void dispose() {
controller.dispose();
super.dispose();
}
Implementation
void dispose() {
_impl.dispose();
}