getCurrentLocation method
Gets the current center location of the map.
Returns null if the map is not ready or an error occurs.
Implementation
Future<LatLng?> getCurrentLocation() {
return _impl.getCurrentLocation();
}
Gets the current center location of the map.
Returns null if the map is not ready or an error occurs.
Future<LatLng?> getCurrentLocation() {
return _impl.getCurrentLocation();
}