moveToLocation method

void moveToLocation(
  1. double lat,
  2. double lng, {
  3. double? zoom,
})

Moves the map to the specified location with optional zoom level.

The map will animate smoothly to the new location using flyTo.

lat and lng are the target latitude and longitude. zoom is optional - if not provided, the current zoom level is maintained.

Implementation

void moveToLocation(double lat, double lng, {double? zoom}) {
  _impl.moveToLocation(lat, lng, zoom: zoom);
}