ready property

Future<void> get ready

Future that completes when the controller is ready to receive commands.

This will complete when the WebViewController (mobile) or iframe (web) is registered and ready. If the controller doesn't become ready within 10 seconds, the future will complete with a timeout error.

Example:

await controller.ready;
controller.moveToLocation(35.6892, 51.3890);

Implementation

Future<void> get ready => _impl.ready;