removeMarker method
Removes a marker from the map by its ID.
Example:
controller.removeMarker('marker1');
Implementation
void removeMarker(String markerId) {
_impl.removeMarker(markerId);
}
Removes a marker from the map by its ID.
Example:
controller.removeMarker('marker1');
void removeMarker(String markerId) {
_impl.removeMarker(markerId);
}