setZoom method
Sets the zoom level of the map.
The map will animate smoothly to the new zoom level.
Implementation
void setZoom(double zoom) {
_impl.setZoom(zoom);
}
Sets the zoom level of the map.
The map will animate smoothly to the new zoom level.
void setZoom(double zoom) {
_impl.setZoom(zoom);
}