coordinates property

List<LatLng> coordinates
final

The list of coordinates that define the line path.

The line will be drawn connecting these points in order.

Implementation

final List<LatLng> coordinates;