isDashed property
Whether the line is dashed or solid.
When true, the line will be rendered with a dashed pattern. When false, the line will be solid. Defaults to false (solid line).
Implementation
final bool isDashed;
Whether the line is dashed or solid.
When true, the line will be rendered with a dashed pattern. When false, the line will be solid. Defaults to false (solid line).
final bool isDashed;