AcceptButtonData class
Data provided to AcceptButtonBuilder.
Contains information about the selected location and button state.
Constructors
- AcceptButtonData({required VoidCallback? onPressed, required bool isEnabled, required LatLng? currentLocation, required String? currentAddress})
-
Creates accept-button data passed to AcceptButtonBuilder.
const
Properties
- currentAddress → String?
-
The address string for the current location.
final
- currentLocation → LatLng?
-
The currently selected location coordinates.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEnabled → bool
-
Whether the button should be enabled.
final
- onPressed → VoidCallback?
-
Callback when button is pressed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited