CenterMarkerBuilder typedef
CenterMarkerBuilder =
Widget Function(BuildContext context)
Builder function for customizing the center marker.
Receives BuildContext. Should return a widget to display at the center of the map indicating the selected location (typically a pin or custom marker icon).
Implementation
typedef CenterMarkerBuilder = Widget Function(BuildContext context);