InvalidApiKeyError class
Invalid or missing API key error (HTTP 480).
Occurs when:
- The API key is invalid
- The API key is not provided in the request header
- Inheritance
-
- Object
- NeshanApiError
- InvalidApiKeyError
Constructors
- InvalidApiKeyError(String message, {String? details})
-
Creates an InvalidApiKeyError instance.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited