InvalidArgumentError class
Invalid request parameters error (HTTP 400).
Occurs when the request parameters are malformed or invalid.
- Inheritance
-
- Object
- NeshanApiError
- InvalidArgumentError
Constructors
- InvalidArgumentError(String message, {String? details})
-
Creates an InvalidArgumentError instance.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited