markers property
Static markers to display on the map alongside the centre-pin overlay.
These markers are placed on the map when it first loads. To add or remove markers at runtime, use controller.
Defaults to an empty list.
Implementation
final List<NeshanMarker> markers;