map library
Map module for the neshan_maps_flutter package.
This module provides core map functionality including:
- Map display widget (NeshanMap)
- Map configuration (NeshanMapConfig)
- Map controller (NeshanMapController)
- Map markers (NeshanMarker)
- Error callbacks (
onError,onLocationError) on NeshanMap
Usage
import 'package:neshan_maps_flutter/map.dart';
import 'package:latlong2/latlong.dart';
NeshanMap(
mapKey: 'your-api-key',
config: NeshanMapConfig(
initialCenter: LatLng(35.6892, 51.3890),
),
);
Classes
- NeshanMap
- A cross-platform widget that displays a Neshan map.
- NeshanMapConfig
- Viewport and style configuration for initializing a NeshanMap.
- NeshanMapController
- Controller for programmatically controlling the Neshan map.
- NeshanMarker
- A model representing a marker on a Neshan map.
Enums
- NeshanMapType
- Enum representing the different types of Neshan maps available.
Constants
- neshanMapHtmlAssetPath → const String
- Path to the HTML asset file for the Neshan map.
Typedefs
- NeshanErrorCallback = void Function(String message, Exception? exception, StackTrace? stackTrace)
- Callback that is called when an error occurs.