markers property
Initial list of markers to display on the map.
These markers are placed on the map when it first finishes loading. To add, remove, or replace markers after the map has loaded, use the methods on controller (NeshanMapController.addMarker, NeshanMapController.removeMarker, NeshanMapController.updateMarkers, NeshanMapController.clearMarkers).
Defaults to an empty list.
Implementation
final List<NeshanMarker> markers;