polygons property
Initial list of polygons to display on the map.
These polygons are placed on the map when it first finishes loading. To add, remove, or replace polygons after the map has loaded, use the methods on controller (NeshanMapController.addPolygon, NeshanMapController.removePolygon, NeshanMapController.updatePolygons, NeshanMapController.clearPolygons).
Defaults to an empty list.
Implementation
final List<NeshanPolygon> polygons;