polylines property
Initial list of polylines to display on the map.
These polylines are placed on the map when it first finishes loading. To add, remove, or replace polylines after the map has loaded, use the methods on controller (NeshanMapController.addPolyline, NeshanMapController.removePolyline, NeshanMapController.updatePolylines, NeshanMapController.clearPolylines).
Defaults to an empty list.
Implementation
final List<NeshanPolyline> polylines;