NeshanMapType enum

Enum representing the different types of Neshan maps available.

Inheritance
Available extensions

Values

neshanVector → const NeshanMapType

Neshan vector map (default)

neshanVectorNight → const NeshanMapType

Neshan vector map (night mode)

neshanRaster → const NeshanMapType

Neshan raster map

neshanRasterNight → const NeshanMapType

Neshan raster map (night mode)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
Returns the string value used by the Neshan SDK.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NeshanMapType>
A constant List of the values in this enum, in order of their declaration.