coordinates property
The list of coordinates that define the polygon boundary.
The coordinates should form a closed loop (first and last point should be the same). For a simple polygon, provide coordinates in clockwise or counter-clockwise order.
Implementation
final List<LatLng> coordinates;